summaryrefslogtreecommitdiff
path: root/tools/gyp/pylib/gyp/generator/make.py
diff options
context:
space:
mode:
authorBen Noordhuis <info@bnoordhuis.nl>2012-04-10 20:01:34 +0200
committerBen Noordhuis <info@bnoordhuis.nl>2012-04-12 01:34:04 +0200
commitaa5961a445acbd2b533ef870eb19733be7b7ede5 (patch)
tree263f6a756c6782bd4eb4596386cd76eead9f9245 /tools/gyp/pylib/gyp/generator/make.py
parente9dcfd4bd280fe3e819b2c992f33dad22bb8a967 (diff)
downloadandroid-node-v8-aa5961a445acbd2b533ef870eb19733be7b7ede5.tar.gz
android-node-v8-aa5961a445acbd2b533ef870eb19733be7b7ede5.tar.bz2
android-node-v8-aa5961a445acbd2b533ef870eb19733be7b7ede5.zip
gyp: fix 'argument list too long' build error
Diffstat (limited to 'tools/gyp/pylib/gyp/generator/make.py')
-rw-r--r--tools/gyp/pylib/gyp/generator/make.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/tools/gyp/pylib/gyp/generator/make.py b/tools/gyp/pylib/gyp/generator/make.py
index e93cb03314..3b01a8d861 100644
--- a/tools/gyp/pylib/gyp/generator/make.py
+++ b/tools/gyp/pylib/gyp/generator/make.py
@@ -525,9 +525,9 @@ d_files := $(wildcard $(foreach f,$(all_deps),$(depsdir)/$(f).d))
ifneq ($(d_files),)
# Rather than include each individual .d file, concatenate them into a
# single file which make is able to load faster. We split this into
# commands that take 1000 files at a time to avoid overflowing the
# command line.
- $(shell cat $(wordlist 1,1000,$(d_files)) > $(depsdir)/all.deps)
+ $(shell cat $(wordlist 1,512,$(d_files)) > $(depsdir)/all.deps)
%(generate_all_deps)s
# make looks for ways to re-generate included makefiles, but in our case, we
# don't have a direct way. Explicitly telling make that it has nothing to do
@@ -525,9 +525,9 @@ d_files := $(wildcard $(foreach f,$(all_deps),$(depsdir)/$(f).d))
# Rather than include each individual .d file, concatenate them into a
# single file which make is able to load faster. We split this into
- # commands that take 1000 files at a time to avoid overflowing the
+ # commands that take 512 files at a time to avoid overflowing the
# command line.